linux-media.vger.kernel.org archive mirror
 help / color / mirror / Atom feed
* [PATCH v6 0/2] media: Add entity types
@ 2016-03-24  8:50 Laurent Pinchart
  2016-03-24  8:50 ` [PATCH v6 1/2] media: Add obj_type field to struct media_entity Laurent Pinchart
                   ` (3 more replies)
  0 siblings, 4 replies; 7+ messages in thread
From: Laurent Pinchart @ 2016-03-24  8:50 UTC (permalink / raw)
  To: linux-media
  Cc: Sakari Ailus, Hans Verkuil, Mauro Carvalho Chehab, Kyungmin Park,
	Sylwester Nawrocki, Prabhakar Lad

Hello,

This patch series adds an obj_type field to the media entity structure. It
is a resend of v5 with the MEDIA_ENTITY_TYPE_INVALID type replaced by
MEDIA_ENTITY_TYPE_BASE to identify media entity instances not embedded in
another structure.

Cc: Kyungmin Park <kyungmin.park@samsung.com>
Cc: Sylwester Nawrocki <s.nawrocki@samsung.com>
Cc: Prabhakar Lad <prabhakar.csengg@gmail.com>

Laurent Pinchart (2):
  media: Add obj_type field to struct media_entity
  media: Rename is_media_entity_v4l2_io to
    is_media_entity_v4l2_video_device

 drivers/media/platform/exynos4-is/media-dev.c   |  4 +-
 drivers/media/platform/omap3isp/ispvideo.c      |  2 +-
 drivers/media/v4l2-core/v4l2-dev.c              |  1 +
 drivers/media/v4l2-core/v4l2-mc.c               |  2 +-
 drivers/media/v4l2-core/v4l2-subdev.c           |  1 +
 drivers/staging/media/davinci_vpfe/vpfe_video.c |  2 +-
 drivers/staging/media/omap4iss/iss_video.c      |  2 +-
 include/media/media-entity.h                    | 78 +++++++++++++------------
 8 files changed, 48 insertions(+), 44 deletions(-)

-- 
Regards,

Laurent Pinchart


^ permalink raw reply	[flat|nested] 7+ messages in thread

* [PATCH v6 1/2] media: Add obj_type field to struct media_entity
  2016-03-24  8:50 [PATCH v6 0/2] media: Add entity types Laurent Pinchart
@ 2016-03-24  8:50 ` Laurent Pinchart
  2016-03-24  8:50 ` [PATCH v6 2/2] media: Rename is_media_entity_v4l2_io to is_media_entity_v4l2_video_device Laurent Pinchart
                   ` (2 subsequent siblings)
  3 siblings, 0 replies; 7+ messages in thread
From: Laurent Pinchart @ 2016-03-24  8:50 UTC (permalink / raw)
  To: linux-media; +Cc: Sakari Ailus, Hans Verkuil, Mauro Carvalho Chehab

Code that processes media entities can require knowledge of the
structure type that embeds a particular media entity instance in order
to cast the entity to the proper object type. This needs is shown by the
presence of the is_media_entity_v4l2_io and is_media_entity_v4l2_subdev
functions.

The implementation of those two functions relies on the entity function
field, which is both a wrong and an inefficient design, without even
mentioning the maintenance issue involved in updating the functions
every time a new entity function is added. Fix this by adding add an
obj_type field to the media entity structure to carry the information.

Signed-off-by: Laurent Pinchart <laurent.pinchart+renesas@ideasonboard.com>
Acked-by: Hans Verkuil <hans.verkuil@cisco.com>
Acked-by: Sakari Ailus <sakari.ailus@linux.intel.com>
---
 drivers/media/v4l2-core/v4l2-dev.c    |  1 +
 drivers/media/v4l2-core/v4l2-subdev.c |  1 +
 include/media/media-entity.h          | 76 ++++++++++++++++++-----------------
 3 files changed, 41 insertions(+), 37 deletions(-)

diff --git a/drivers/media/v4l2-core/v4l2-dev.c b/drivers/media/v4l2-core/v4l2-dev.c
index d8e5994cccf1..70b559d7ca80 100644
--- a/drivers/media/v4l2-core/v4l2-dev.c
+++ b/drivers/media/v4l2-core/v4l2-dev.c
@@ -735,6 +735,7 @@ static int video_register_media_controller(struct video_device *vdev, int type)
 	if (!vdev->v4l2_dev->mdev)
 		return 0;
 
+	vdev->entity.obj_type = MEDIA_ENTITY_TYPE_VIDEO_DEVICE;
 	vdev->entity.function = MEDIA_ENT_F_UNKNOWN;
 
 	switch (type) {
diff --git a/drivers/media/v4l2-core/v4l2-subdev.c b/drivers/media/v4l2-core/v4l2-subdev.c
index d63083803144..0fa60801a428 100644
--- a/drivers/media/v4l2-core/v4l2-subdev.c
+++ b/drivers/media/v4l2-core/v4l2-subdev.c
@@ -584,6 +584,7 @@ void v4l2_subdev_init(struct v4l2_subdev *sd, const struct v4l2_subdev_ops *ops)
 	sd->host_priv = NULL;
 #if defined(CONFIG_MEDIA_CONTROLLER)
 	sd->entity.name = sd->name;
+	sd->entity.obj_type = MEDIA_ENTITY_TYPE_V4L2_SUBDEV;
 	sd->entity.function = MEDIA_ENT_F_V4L2_SUBDEV_UNKNOWN;
 #endif
 }
-- 
2.7.3


^ permalink raw reply related	[flat|nested] 7+ messages in thread

* [PATCH v6 2/2] media: Rename is_media_entity_v4l2_io to is_media_entity_v4l2_video_device
  2016-03-24  8:50 [PATCH v6 0/2] media: Add entity types Laurent Pinchart
  2016-03-24  8:50 ` [PATCH v6 1/2] media: Add obj_type field to struct media_entity Laurent Pinchart
@ 2016-03-24  8:50 ` Laurent Pinchart
  2016-03-24 11:38 ` [PATCH v6 0/2] media: Add entity types Mauro Carvalho Chehab
  2016-03-26 20:27 ` Lad, Prabhakar
  3 siblings, 0 replies; 7+ messages in thread
From: Laurent Pinchart @ 2016-03-24  8:50 UTC (permalink / raw)
  To: linux-media; +Cc: Sakari Ailus, Hans Verkuil, Mauro Carvalho Chehab

All users of is_media_entity_v4l2_io() (the exynos4-is, omap3isp,
davince_vpfe and omap4iss drivers and the v4l2-mc power management code)
use the function to check whether entities are video_device instances,
either to ensure they can cast the entity to a struct video_device, or
to count the number of video nodes users.

The purpose of the function is thus to identify whether the media entity
instance is an instance of the video_device object, not to check whether
it can perform I/O. Rename it accordingly, we will introduce a more
specific is_media_entity_v4l2_io() check when needed.

Signed-off-by: Laurent Pinchart <laurent.pinchart+renesas@ideasonboard.com>
Acked-by: Hans Verkuil <hans.verkuil@cisco.com>
Acked-by: Sakari Ailus <sakari.ailus@linux.intel.com>
---
 drivers/media/platform/exynos4-is/media-dev.c   | 4 ++--
 drivers/media/platform/omap3isp/ispvideo.c      | 2 +-
 drivers/media/v4l2-core/v4l2-mc.c               | 2 +-
 drivers/staging/media/davinci_vpfe/vpfe_video.c | 2 +-
 drivers/staging/media/omap4iss/iss_video.c      | 2 +-
 include/media/media-entity.h                    | 4 ++--
 6 files changed, 8 insertions(+), 8 deletions(-)

diff --git a/drivers/media/platform/exynos4-is/media-dev.c b/drivers/media/platform/exynos4-is/media-dev.c
index feb521f28e14..9a377d9dd58a 100644
--- a/drivers/media/platform/exynos4-is/media-dev.c
+++ b/drivers/media/platform/exynos4-is/media-dev.c
@@ -1130,7 +1130,7 @@ static int __fimc_md_modify_pipelines(struct media_entity *entity, bool enable,
 	media_entity_graph_walk_start(graph, entity);
 
 	while ((entity = media_entity_graph_walk_next(graph))) {
-		if (!is_media_entity_v4l2_io(entity))
+		if (!is_media_entity_v4l2_video_device(entity))
 			continue;
 
 		ret  = __fimc_md_modify_pipeline(entity, enable);
@@ -1145,7 +1145,7 @@ err:
 	media_entity_graph_walk_start(graph, entity_err);
 
 	while ((entity_err = media_entity_graph_walk_next(graph))) {
-		if (!is_media_entity_v4l2_io(entity_err))
+		if (!is_media_entity_v4l2_video_device(entity_err))
 			continue;
 
 		__fimc_md_modify_pipeline(entity_err, !enable);
diff --git a/drivers/media/platform/omap3isp/ispvideo.c b/drivers/media/platform/omap3isp/ispvideo.c
index ac76d2901501..1b1a95d546f6 100644
--- a/drivers/media/platform/omap3isp/ispvideo.c
+++ b/drivers/media/platform/omap3isp/ispvideo.c
@@ -251,7 +251,7 @@ static int isp_video_get_graph_data(struct isp_video *video,
 		if (entity == &video->video.entity)
 			continue;
 
-		if (!is_media_entity_v4l2_io(entity))
+		if (!is_media_entity_v4l2_video_device(entity))
 			continue;
 
 		__video = to_isp_video(media_entity_to_video_device(entity));
diff --git a/drivers/media/v4l2-core/v4l2-mc.c b/drivers/media/v4l2-core/v4l2-mc.c
index 2228cd3a846e..ca94bded3386 100644
--- a/drivers/media/v4l2-core/v4l2-mc.c
+++ b/drivers/media/v4l2-core/v4l2-mc.c
@@ -263,7 +263,7 @@ static int pipeline_pm_use_count(struct media_entity *entity,
 	media_entity_graph_walk_start(graph, entity);
 
 	while ((entity = media_entity_graph_walk_next(graph))) {
-		if (is_media_entity_v4l2_io(entity))
+		if (is_media_entity_v4l2_video_device(entity))
 			use += entity->use_count;
 	}
 
diff --git a/drivers/staging/media/davinci_vpfe/vpfe_video.c b/drivers/staging/media/davinci_vpfe/vpfe_video.c
index db49af90217e..7d8fa34f31f3 100644
--- a/drivers/staging/media/davinci_vpfe/vpfe_video.c
+++ b/drivers/staging/media/davinci_vpfe/vpfe_video.c
@@ -154,7 +154,7 @@ static int vpfe_prepare_pipeline(struct vpfe_video_device *video)
 	while ((entity = media_entity_graph_walk_next(&graph))) {
 		if (entity == &video->video_dev.entity)
 			continue;
-		if (!is_media_entity_v4l2_io(entity))
+		if (!is_media_entity_v4l2_video_device(entity))
 			continue;
 		far_end = to_vpfe_video(media_entity_to_video_device(entity));
 		if (far_end->type == V4L2_BUF_TYPE_VIDEO_OUTPUT)
diff --git a/drivers/staging/media/omap4iss/iss_video.c b/drivers/staging/media/omap4iss/iss_video.c
index f54349bce4de..cf8da23558bb 100644
--- a/drivers/staging/media/omap4iss/iss_video.c
+++ b/drivers/staging/media/omap4iss/iss_video.c
@@ -223,7 +223,7 @@ iss_video_far_end(struct iss_video *video)
 		if (entity == &video->video.entity)
 			continue;
 
-		if (!is_media_entity_v4l2_io(entity))
+		if (!is_media_entity_v4l2_video_device(entity))
 			continue;
 
 		far_end = to_iss_video(media_entity_to_video_device(entity));
diff --git a/include/media/media-entity.h b/include/media/media-entity.h
index 6dc9e4e8cbd4..1986340a8cf2 100644
--- a/include/media/media-entity.h
+++ b/include/media/media-entity.h
@@ -188,10 +188,38 @@ struct media_entity_operations {
 };
 
 /**
+ * enum media_entity_type - Media entity type
+ *
+ * @MEDIA_ENTITY_TYPE_BASE:
+ *	The entity isn't embedded in another subsystem structure.
+ * @MEDIA_ENTITY_TYPE_VIDEO_DEVICE:
+ *	The entity is embedded in a struct video_device instance.
+ * @MEDIA_ENTITY_TYPE_V4L2_SUBDEV:
+ *	The entity is embedded in a struct v4l2_subdev instance.
+ *
+ * Media entity objects are often not instantiated directly, but the media
+ * entity structure is inherited by (through embedding) other subsystem-specific
+ * structures. The media entity type identifies the type of the subclass
+ * structure that implements a media entity instance.
+ *
+ * This allows runtime type identification of media entities and safe casting to
+ * the correct object type. For instance, a media entity structure instance
+ * embedded in a v4l2_subdev structure instance will have the type
+ * MEDIA_ENTITY_TYPE_V4L2_SUBDEV and can safely be cast to a v4l2_subdev
+ * structure using the container_of() macro.
+ */
+enum media_entity_type {
+	MEDIA_ENTITY_TYPE_BASE,
+	MEDIA_ENTITY_TYPE_VIDEO_DEVICE,
+	MEDIA_ENTITY_TYPE_V4L2_SUBDEV,
+};
+
+/**
  * struct media_entity - A media entity graph object.
  *
  * @graph_obj:	Embedded structure containing the media object common data.
  * @name:	Entity name.
+ * @obj_type:	Type of the object that implements the media_entity.
  * @function:	Entity main function, as defined in uapi/media.h
  *		(MEDIA_ENT_F_*)
  * @flags:	Entity flags, as defined in uapi/media.h (MEDIA_ENT_FL_*)
@@ -220,6 +248,7 @@ struct media_entity_operations {
 struct media_entity {
 	struct media_gobj graph_obj;	/* must be first field in struct */
 	const char *name;
+	enum media_entity_type obj_type;
 	u32 function;
 	unsigned long flags;
 
@@ -329,56 +358,29 @@ static inline u32 media_gobj_gen_id(enum media_gobj_type type, u64 local_id)
 }
 
 /**
  * is_media_entity_v4l2_io() - identify if the entity main function
  *			       is a V4L2 I/O
  *
  * @entity:	pointer to entity
  *
- * Return: true if the entity main function is one of the V4L2 I/O types
- *	(video, VBI or SDR radio); false otherwise.
+ * Return: true if the entity is an instance of a video_device object and can
+ * safely be cast to a struct video_device using the container_of() macro, or
+ * false otherwise.
  */
 static inline bool is_media_entity_v4l2_io(struct media_entity *entity)
 {
-	if (!entity)
-		return false;
-
-	switch (entity->function) {
-	case MEDIA_ENT_F_IO_V4L:
-	case MEDIA_ENT_F_IO_VBI:
-	case MEDIA_ENT_F_IO_SWRADIO:
-		return true;
-	default:
-		return false;
-	}
+	return entity && entity->obj_type == MEDIA_ENTITY_TYPE_VIDEO_DEVICE;
 }
 
 /**
- * is_media_entity_v4l2_subdev - return true if the entity main function is
- *				 associated with the V4L2 API subdev usage
- *
+ * is_media_entity_v4l2_subdev() - Check if the entity is a v4l2_subdev
  * @entity:	pointer to entity
  *
- * This is an ancillary function used by subdev-based V4L2 drivers.
- * It checks if the entity function is one of functions used by a V4L2 subdev,
- * e. g. camera-relatef functions, analog TV decoder, TV tuner, V4L2 DSPs.
+ * Return: true if the entity is an instance of a v4l2_subdev object and can
+ * safely be cast to a struct v4l2_subdev using the container_of() macro, or
+ * false otherwise.
  */
 static inline bool is_media_entity_v4l2_subdev(struct media_entity *entity)
 {
-	if (!entity)
-		return false;
-
-	switch (entity->function) {
-	case MEDIA_ENT_F_V4L2_SUBDEV_UNKNOWN:
-	case MEDIA_ENT_F_CAM_SENSOR:
-	case MEDIA_ENT_F_FLASH:
-	case MEDIA_ENT_F_LENS:
-	case MEDIA_ENT_F_ATV_DECODER:
-	case MEDIA_ENT_F_TUNER:
-		return true;
-
-	default:
-		return false;
-	}
+	return entity && entity->obj_type == MEDIA_ENTITY_TYPE_V4L2_SUBDEV;
 }
 
 /**
@@ -329,56 +358,29 @@ static inline u32 media_gobj_gen_id(enum media_gobj_type type, u64 local_id)
 
 /**
- * is_media_entity_v4l2_io() - identify if the entity main function
- *			       is a V4L2 I/O
- *
+ * is_media_entity_v4l2_io() - Check if the entity is a video_device
  * @entity:	pointer to entity
  *
diff --git a/include/media/media-entity.h b/include/media/media-entity.h
index 1986340a8cf2..e0295eefd702 100644
--- a/include/media/media-entity.h
+++ b/include/media/media-entity.h
@@ -358,14 +358,14 @@ static inline u32 media_gobj_gen_id(enum media_gobj_type type, u64 local_id)
 }
 
 /**
  * is_media_entity_v4l2_io() - Check if the entity is a video_device
  * @entity:	pointer to entity
  *
  * Return: true if the entity is an instance of a video_device object and can
  * safely be cast to a struct video_device using the container_of() macro, or
  * false otherwise.
  */
-static inline bool is_media_entity_v4l2_io(struct media_entity *entity)
+static inline bool is_media_entity_v4l2_video_device(struct media_entity *entity)
 {
 	return entity && entity->obj_type == MEDIA_ENTITY_TYPE_VIDEO_DEVICE;
 }
@@ -358,14 +358,14 @@ static inline u32 media_gobj_gen_id(enum media_gobj_type type, u64 local_id)
 
 /**
- * is_media_entity_v4l2_io() - Check if the entity is a video_device
+ * is_media_entity_v4l2_video_device() - Check if the entity is a video_device
  * @entity:	pointer to entity
  *
-- 
2.7.3


^ permalink raw reply related	[flat|nested] 7+ messages in thread

* Re: [PATCH v6 0/2] media: Add entity types
  2016-03-24  8:50 [PATCH v6 0/2] media: Add entity types Laurent Pinchart
  2016-03-24  8:50 ` [PATCH v6 1/2] media: Add obj_type field to struct media_entity Laurent Pinchart
  2016-03-24  8:50 ` [PATCH v6 2/2] media: Rename is_media_entity_v4l2_io to is_media_entity_v4l2_video_device Laurent Pinchart
@ 2016-03-24 11:38 ` Mauro Carvalho Chehab
  2016-03-24 11:54   ` Laurent Pinchart
  2016-03-26 20:27 ` Lad, Prabhakar
  3 siblings, 1 reply; 7+ messages in thread
From: Mauro Carvalho Chehab @ 2016-03-24 11:38 UTC (permalink / raw)
  To: Laurent Pinchart
  Cc: linux-media, Sakari Ailus, Hans Verkuil, Kyungmin Park,
	Sylwester Nawrocki, Prabhakar Lad

Em Thu, 24 Mar 2016 10:50:06 +0200
Laurent Pinchart <laurent.pinchart+renesas@ideasonboard.com> escreveu:

> Hello,
> 
> This patch series adds an obj_type field to the media entity structure. It
> is a resend of v5 with the MEDIA_ENTITY_TYPE_INVALID type replaced by
> MEDIA_ENTITY_TYPE_BASE to identify media entity instances not embedded in
> another structure.

Patches looked OK to me. I'll apply them next week.

> 
> Cc: Kyungmin Park <kyungmin.park@samsung.com>
> Cc: Sylwester Nawrocki <s.nawrocki@samsung.com>
> Cc: Prabhakar Lad <prabhakar.csengg@gmail.com>
> 
> Laurent Pinchart (2):
>   media: Add obj_type field to struct media_entity
>   media: Rename is_media_entity_v4l2_io to
>     is_media_entity_v4l2_video_device
> 
>  drivers/media/platform/exynos4-is/media-dev.c   |  4 +-
>  drivers/media/platform/omap3isp/ispvideo.c      |  2 +-
>  drivers/media/v4l2-core/v4l2-dev.c              |  1 +
>  drivers/media/v4l2-core/v4l2-mc.c               |  2 +-
>  drivers/media/v4l2-core/v4l2-subdev.c           |  1 +
>  drivers/staging/media/davinci_vpfe/vpfe_video.c |  2 +-
>  drivers/staging/media/omap4iss/iss_video.c      |  2 +-
>  include/media/media-entity.h                    | 78 +++++++++++++------------
>  8 files changed, 48 insertions(+), 44 deletions(-)
> 


-- 
Thanks,
Mauro

^ permalink raw reply	[flat|nested] 7+ messages in thread

* Re: [PATCH v6 0/2] media: Add entity types
  2016-03-24 11:38 ` [PATCH v6 0/2] media: Add entity types Mauro Carvalho Chehab
@ 2016-03-24 11:54   ` Laurent Pinchart
  2016-03-24 11:57     ` Mauro Carvalho Chehab
  0 siblings, 1 reply; 7+ messages in thread
From: Laurent Pinchart @ 2016-03-24 11:54 UTC (permalink / raw)
  To: Mauro Carvalho Chehab
  Cc: Laurent Pinchart, linux-media, Sakari Ailus, Hans Verkuil,
	Kyungmin Park, Sylwester Nawrocki, Prabhakar Lad

On Thursday 24 Mar 2016 08:38:40 Mauro Carvalho Chehab wrote:
> Em Thu, 24 Mar 2016 10:50:06 +0200 Laurent Pinchart escreveu:
> > Hello,
> > 
> > This patch series adds an obj_type field to the media entity structure. It
> > is a resend of v5 with the MEDIA_ENTITY_TYPE_INVALID type replaced by
> > MEDIA_ENTITY_TYPE_BASE to identify media entity instances not embedded in
> > another structure.
> 
> Patches looked OK to me. I'll apply them next week.

Thank you. I'll send a patch series for the VSP driver that applies on top of 
these two patches, and will send the pull request when media entity types will 
be merged in your tree.

> > Cc: Kyungmin Park <kyungmin.park@samsung.com>
> > Cc: Sylwester Nawrocki <s.nawrocki@samsung.com>
> > Cc: Prabhakar Lad <prabhakar.csengg@gmail.com>
> > 
> > Laurent Pinchart (2):
> >   media: Add obj_type field to struct media_entity
> >   media: Rename is_media_entity_v4l2_io to
> >   
> >     is_media_entity_v4l2_video_device
> >  
> >  drivers/media/platform/exynos4-is/media-dev.c   |  4 +-
> >  drivers/media/platform/omap3isp/ispvideo.c      |  2 +-
> >  drivers/media/v4l2-core/v4l2-dev.c              |  1 +
> >  drivers/media/v4l2-core/v4l2-mc.c               |  2 +-
> >  drivers/media/v4l2-core/v4l2-subdev.c           |  1 +
> >  drivers/staging/media/davinci_vpfe/vpfe_video.c |  2 +-
> >  drivers/staging/media/omap4iss/iss_video.c      |  2 +-
> >  include/media/media-entity.h                    | 78 ++++++++++----------
> >  8 files changed, 48 insertions(+), 44 deletions(-)

-- 
Regards,

Laurent Pinchart


^ permalink raw reply	[flat|nested] 7+ messages in thread

* Re: [PATCH v6 0/2] media: Add entity types
  2016-03-24 11:54   ` Laurent Pinchart
@ 2016-03-24 11:57     ` Mauro Carvalho Chehab
  0 siblings, 0 replies; 7+ messages in thread
From: Mauro Carvalho Chehab @ 2016-03-24 11:57 UTC (permalink / raw)
  To: Laurent Pinchart
  Cc: Laurent Pinchart, linux-media, Sakari Ailus, Hans Verkuil,
	Kyungmin Park, Sylwester Nawrocki, Prabhakar Lad

Em Thu, 24 Mar 2016 13:54:57 +0200
Laurent Pinchart <laurent.pinchart@ideasonboard.com> escreveu:

> On Thursday 24 Mar 2016 08:38:40 Mauro Carvalho Chehab wrote:
> > Em Thu, 24 Mar 2016 10:50:06 +0200 Laurent Pinchart escreveu:  
> > > Hello,
> > > 
> > > This patch series adds an obj_type field to the media entity structure. It
> > > is a resend of v5 with the MEDIA_ENTITY_TYPE_INVALID type replaced by
> > > MEDIA_ENTITY_TYPE_BASE to identify media entity instances not embedded in
> > > another structure.  
> > 
> > Patches looked OK to me. I'll apply them next week.  
> 
> Thank you. I'll send a patch series for the VSP driver that applies on top of 
> these two patches, and will send the pull request when media entity types will 
> be merged in your tree.

Well, you can put the VSP patches and this series on the same pull request.

> 
> > > Cc: Kyungmin Park <kyungmin.park@samsung.com>
> > > Cc: Sylwester Nawrocki <s.nawrocki@samsung.com>
> > > Cc: Prabhakar Lad <prabhakar.csengg@gmail.com>
> > > 
> > > Laurent Pinchart (2):
> > >   media: Add obj_type field to struct media_entity
> > >   media: Rename is_media_entity_v4l2_io to
> > >   
> > >     is_media_entity_v4l2_video_device
> > >  
> > >  drivers/media/platform/exynos4-is/media-dev.c   |  4 +-
> > >  drivers/media/platform/omap3isp/ispvideo.c      |  2 +-
> > >  drivers/media/v4l2-core/v4l2-dev.c              |  1 +
> > >  drivers/media/v4l2-core/v4l2-mc.c               |  2 +-
> > >  drivers/media/v4l2-core/v4l2-subdev.c           |  1 +
> > >  drivers/staging/media/davinci_vpfe/vpfe_video.c |  2 +-
> > >  drivers/staging/media/omap4iss/iss_video.c      |  2 +-
> > >  include/media/media-entity.h                    | 78 ++++++++++----------
> > >  8 files changed, 48 insertions(+), 44 deletions(-)  
> 


-- 
Thanks,
Mauro

^ permalink raw reply	[flat|nested] 7+ messages in thread

* Re: [PATCH v6 0/2] media: Add entity types
  2016-03-24  8:50 [PATCH v6 0/2] media: Add entity types Laurent Pinchart
                   ` (2 preceding siblings ...)
  2016-03-24 11:38 ` [PATCH v6 0/2] media: Add entity types Mauro Carvalho Chehab
@ 2016-03-26 20:27 ` Lad, Prabhakar
  3 siblings, 0 replies; 7+ messages in thread
From: Lad, Prabhakar @ 2016-03-26 20:27 UTC (permalink / raw)
  To: Laurent Pinchart
  Cc: linux-media, Sakari Ailus, Hans Verkuil, Mauro Carvalho Chehab,
	Kyungmin Park, Sylwester Nawrocki

Hi Laurent,

Thanks for the patches.


On Thu, Mar 24, 2016 at 8:50 AM, Laurent Pinchart
<laurent.pinchart+renesas@ideasonboard.com> wrote:
> Hello,
>
> This patch series adds an obj_type field to the media entity structure. It
> is a resend of v5 with the MEDIA_ENTITY_TYPE_INVALID type replaced by
> MEDIA_ENTITY_TYPE_BASE to identify media entity instances not embedded in
> another structure.
>
> Cc: Kyungmin Park <kyungmin.park@samsung.com>
> Cc: Sylwester Nawrocki <s.nawrocki@samsung.com>
> Cc: Prabhakar Lad <prabhakar.csengg@gmail.com>
>
> Laurent Pinchart (2):
>   media: Add obj_type field to struct media_entity
>   media: Rename is_media_entity_v4l2_io to
>     is_media_entity_v4l2_video_device
>

Acked-by: Lad, Prabhakar <prabhakar.csengg@gmail.com>

Cheers,
--Prabhakar Lad

^ permalink raw reply	[flat|nested] 7+ messages in thread

end of thread, other threads:[~2016-03-26 20:28 UTC | newest]

Thread overview: 7+ messages (download: mbox.gz / follow: Atom feed)
-- links below jump to the message on this page --
2016-03-24  8:50 [PATCH v6 0/2] media: Add entity types Laurent Pinchart
2016-03-24  8:50 ` [PATCH v6 1/2] media: Add obj_type field to struct media_entity Laurent Pinchart
2016-03-24  8:50 ` [PATCH v6 2/2] media: Rename is_media_entity_v4l2_io to is_media_entity_v4l2_video_device Laurent Pinchart
2016-03-24 11:38 ` [PATCH v6 0/2] media: Add entity types Mauro Carvalho Chehab
2016-03-24 11:54   ` Laurent Pinchart
2016-03-24 11:57     ` Mauro Carvalho Chehab
2016-03-26 20:27 ` Lad, Prabhakar

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for NNTP newsgroup(s).